##  Overview
Microsoft Azure API Center is a service that provides a centralized, organization-wide catalog for all your APIs, including MCP servers. You can automate the discovery of MCP servers registered in Microsoft Azure API Center by setting up an integration with SAP LeanIX. This integration identifies registered MCP servers and lists them in the AI agent discovery inbox in SAP LeanIX. You can review discovered items and decide which ones to add to your inventory or reject.
By linking MCP servers to applications and AI agents, you gain a holistic view of connections and dependencies of AI-related components in your enterprise architecture landscape. This approach helps identify additional optimization opportunities, such as building agent chains, and promotes the reuse of existing tools.
In the SAP LeanIX meta model, MCP servers are represented as a subtype of interface fact sheets. For additional information, see [How to Model MCP Servers](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a9c8b7a441014ab9edc183392ab74__section_snq_bml_dhc).
